/*
 * Example for GainAMP click
 *
 * Date         Jan 2017
 * Author       Marton B.
 * Copyright    GNU Public License v2
 *
 * Test configuration PIC32 :
 *  MCU           :	P32MX795F512L
 *  Dev. Board    :	EasyPIC Fusion v7
 *  SW            :	mikroC PRO for PIC32 v3.6.0
 *
 * Board setup:
 * 1. RG0 and RG1 pull-down.
 * 2. BUTTON PRESS LEVEL for PORTG/L set to VCC. 
 *
 ******************************************************************************/

#include "gain_amp.h"

#define PIN_DIR_IN 1
#define PIN_DIR_OUT 0
#define PIN_ALL_DIR_OUT 0x00


sbit GAIN_AMP_CS at RC2_bit;
sbit GAIN_AMP_SHDN at RC1_bit;

sbit GAIN_AMP_CS_DIR at TRISC2_bit;
sbit GAIN_AMP_SHDN_DIR at TRISC1_bit;


static uint8_t gain;
static uint8_t byte;

static void system_init( void );


static void system_init( void )
{
    AD1PCFG = 0xFFFF;

    GAIN_AMP_CS_DIR = PIN_DIR_OUT;
    GAIN_AMP_SHDN_DIR = PIN_DIR_OUT;
    GAIN_AMP_CS = 1;

    // Input pins for buttons.
    TRISG0_bit = PIN_DIR_IN;
    TRISG1_bit = PIN_DIR_IN;

    // Output pins for displaying contol byte.
    TRISB = PIN_ALL_DIR_OUT;

    // Initialize SPI.
    SPI3_Init_Advanced( 
        _SPI_MASTER, 
        _SPI_8_BIT, 
        1, 
        _SPI_SS_DISABLE,            
        _SPI_DATA_SAMPLE_MIDDLE, 
        _SPI_CLK_IDLE_HIGH,
        _SPI_ACTIVE_2_IDLE 
    );

    // Initialize GainAMP module.
    gain_amp_init( SPI3_Write );

    gain = 0;
}

void main()
{
    system_init();

    gain_amp_set(GAIN_AMP_NOMINAL_0, GAIN_AMP_SW_SHUTDOWN);

    while( 1 )
    {
        if(Button(&PORTG, 1, 100, 1))
        {
            byte = gain_amp_set(++gain & 0x07, GAIN_AMP_SW_SHUTDOWN);
            PORTB = byte;
        }
        if(Button(&PORTG, 0, 100, 1))
        {
            byte = gain_amp_set(--gain & 0x07, GAIN_AMP_SW_SHUTDOWN);
            PORTB = byte;
        }
    }
}

/************************************************************ END OF FILE *****/